==> QupZilla-2.0.0.tar.xz: QupZilla-2.0.0/src/plugins/StatusBarIcons/translations/zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.0">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="32"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>修改图像载入设置（逐站点及全局）</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="56"/>
        <source>Current page settings</source>
        <translation>当前页面设置</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="59"/>
        <source>Disable loading images (temporarily)</source>
        <translation>禁止载入图片（临时）</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="62"/>
        <source>Enable loading images (temporarily)</source>
        <translation>允许载入图片（临时）</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="66"/>
        <source>Global settings</source>
        <translation>全局设置</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="68"/>
        <source>Automatically load images</source>
        <translation>自动载入图片</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="33"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>修改 JavaScript 设置（逐站点及全局）</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="48"/>
        <source>Current page settings</source>
        <translation>当前页面设置</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="51"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>禁止 JavaScript（临时）</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="54"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>允许 JavaScript（临时）</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="63"/>
        <source>Global settings</source>
        <translation>全局设置</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="64"/>
        <source>Manage JavaScript settings</source>
        <translation>管理 JavaScript 设置</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="66"/>
        <source>Proxy configuration</source>
        <translation>代理服务器设置</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="68"/>
        <source>Select proxy</source>
        <translation>选择代理服务器</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="82"/>
        <source>Empty</source>
        <translation>空</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="86"/>
        <source>Manage proxies</source>
        <translation>管理代理的使用</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="99"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>显示网络状态和代理服务器&lt;br/&gt;&lt;br/&gt;&lt;b&gt;网络：&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;代理服务器：&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="102"/>
        <source>Connected</source>
        <translation>联机</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="105"/>
        <source>Offline</source>
        <translation>离线</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="110"/>
        <source>System proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="114"/>
        <source>No proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="118"/>
        <source>PAC (Proxy Auto-Config)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="122"/>
        <source>User defined</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>代理服务器管理器</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>选择代理服务器：</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="55"/>
        <source>Add proxy</source>
        <translation>添加代理服务器</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>移除代理服务器</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>没有设定代理服务器。可点击&lt;B&gt;添加&lt;/B&gt;按钮来添加一个。</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>所有修改都要在点击&lt;B&gt;保存&lt;/B&gt;之后才能生效。</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="55"/>
        <source>Name of proxy:</source>
        <translation>代理服务器名称：</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="68"/>
        <source>Remove current proxy</source>
        <translation>移除当前代理服务器</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="68"/>
        <source>Are you sure to remove current proxy?</source>
        <translation>确定要移除所选的代理服务器吗？</translation>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="20"/>
        <source>Do not use proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="27"/>
        <source>Use different proxy for https connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="34"/>
        <source>&lt;b&gt;Exceptions&lt;/b&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="43"/>
        <source>Don&apos;t use on:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="58"/>
        <source>HTTP</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="63"/>
        <source>SOCKS5</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="74"/>
        <location filename="../sbi_proxywidget.ui" line="220"/>
        <source>Port:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <location filename="../sbi_proxywidget.ui" line="243"/>
        <source>Username:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="121"/>
        <location filename="../sbi_proxywidget.ui" line="253"/>
        <source>Password:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="146"/>
        <source>Use script for automatic configuration:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="153"/>
        <source>System proxy configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="162"/>
        <source>Proxy Auto-Config (.pac) file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="187"/>
        <source>Manual configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="210"/>
        <source>Server:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>状态栏图标</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;H3&gt;状态栏图标&lt;/H3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>以下图标将在状态栏中显示：</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>网页图片设置图标</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>JavaScript 设置图标</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>网络状态和代理设置图标</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="118"/>
        <source>Zoom widget</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SBI_ZoomWidget</name>
    <message>
        <location filename="../sbi_zoomwidget.cpp" line="47"/>
        <source>Zoom: %1%</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> QupZilla-2.1.0.tar.xz: QupZilla-2.1.0/src/plugins/StatusBarIcons/translations/zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="32"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>修改图像载入设置（逐站点及全局）</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="56"/>
        <source>Current Page Settings</source>
        <translation>当前页面设置</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="59"/>
        <source>Disable loading images (temporarily)</source>
        <translation>禁止载入图片（临时）</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="62"/>
        <source>Enable loading images (temporarily)</source>
        <translation>允许载入图片（临时）</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="66"/>
        <source>Global Settings</source>
        <translation>全局设置</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="68"/>
        <source>Automatically load images</source>
        <translation>自动载入图片</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="33"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>修改 JavaScript 设置（逐站点及全局）</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="50"/>
        <source>Current Page Settings</source>
        <translation>当前页面设置</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="53"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>禁止 JavaScript（临时）</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="56"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>允许 JavaScript（临时）</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="65"/>
        <source>Global Settings</source>
        <translation>全局设置</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="66"/>
        <source>Manage JavaScript settings</source>
        <translation>管理 JavaScript 设置</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="64"/>
        <source>Proxy Configuration</source>
        <translation>代理服务器配置</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="66"/>
        <source>Select proxy</source>
        <translation>选择代理服务器</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="80"/>
        <source>Empty</source>
        <translation>空</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="84"/>
        <source>Manage proxies</source>
        <translation>管理代理的使用</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="97"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>显示网络状态和代理服务器&lt;br/&gt;&lt;br/&gt;&lt;b&gt;网络：&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;代理服务器：&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="100"/>
        <source>Connected</source>
        <translation>联机</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="103"/>
        <source>Offline</source>
        <translation>离线</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="108"/>
        <source>System proxy</source>
        <translation>系统代理</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="112"/>
        <source>No proxy</source>
        <translation>无代理服务器</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="116"/>
        <source>User defined</source>
        <translation>用户定义</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>代理服务器管理器</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>选择代理服务器：</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Add proxy</source>
        <translation>添加代理服务器</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>移除代理服务器</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>没有设定代理服务器。可点击&lt;B&gt;添加&lt;/B&gt;按钮来添加一个。</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>所有修改都要在点击&lt;B&gt;保存&lt;/B&gt;之后才能生效。</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Name of proxy:</source>
        <translation>代理服务器名称：</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Remove current proxy</source>
        <translation>移除当前代理服务器</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Are you sure you want to remove current proxy?</source>
        <translation>您确定要移除当前的代理？</translation>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>表单</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="23"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="28"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="39"/>
        <source>Port:</source>
        <translation>端口：</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="76"/>
        <source>Username:</source>
        <translation>用户名：</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="86"/>
        <source>Password:</source>
        <translation>密码：</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <source>S&amp;ystem proxy configuration</source>
        <translation>系统代理配置(&amp;Y)</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="118"/>
        <source>&amp;Manual configuration</source>
        <translation>手动配置(&amp;M)</translation>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>状态栏图标</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;H3&gt;状态栏图标&lt;/H3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>以下图标将在状态栏中显示：</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>网页图片设置图标</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>JavaScript 设置图标</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>网络状态和代理设置图标</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="118"/>
        <source>Zoom widget</source>
        <translation>缩放控件</translation>
    </message>
</context>
<context>
    <name>SBI_ZoomWidget</name>
    <message>
        <location filename="../sbi_zoomwidget.cpp" line="47"/>
        <source>Zoom: %1%</source>
        <translation>缩放：%1%</translation>
    </message>
</context>
</TS>
